@@ -523,13 +523,7 @@ read_relay_log_description_event(IO_CACHE *cur_log, ulonglong start_pos,
   Format_description_log_event *fdev;
   bool found= false;
 
-  /*
-    By default the relay log is in binlog format 3 (4.0).
-    Even if format is 4, this will work enough to read the first event
-    (Format_desc) (remember that format 4 is just lenghtened compared to format
-    3; format 3 is a prefix of format 4).
-  */
-  fdev= new Format_description_log_event(3);
+  fdev= new Format_description_log_event(4);
 
   while (!found)
   {
@@ -664,14 +658,7 @@ int init_relay_log_pos(Relay_log_info* rli,const char* log,
     running, say, CHANGE MASTER.
   */
   delete rli->relay_log.description_event_for_exec;
-  /*
-    By default the relay log is in binlog format 3 (4.0).
-    Even if format is 4, this will work enough to read the first event
-    (Format_desc) (remember that format 4 is just lenghtened compared to format
-    3; format 3 is a prefix of format 4).
-  */
-  rli->relay_log.description_event_for_exec= new
-    Format_description_log_event(3);
+  rli->relay_log.description_event_for_exec= new Format_description_log_event(4);
 
   mysql_mutex_lock(log_lock);
 
@@ -2529,23 +2516,6 @@ rpl_group_info::unmark_start_commit()
 
   e= this->parallel_entry;
   mysql_mutex_lock(&e->LOCK_parallel_entry);
-  /*
-    Assert that we have not already wrongly completed this GCO and signalled
-    the next one to start, only to now unmark and make the signal invalid.
-    This is to catch problems like MDEV-34696.
-
-    The error inject rpl_parallel_simulate_temp_err_xid is used to test this
-    precise situation, that we handle it gracefully if it somehow occurs in a
-    release build. So disable the assert in this case.
-  */
-#ifndef DBUG_OFF
-  bool allow_unmark_after_complete= false;
-  DBUG_EXECUTE_IF("rpl_parallel_simulate_temp_err_xid",
-                  allow_unmark_after_complete= true;);
-  DBUG_ASSERT(!gco->next_gco ||
-              gco->next_gco->wait_count > e->count_committing_event_groups ||
-              allow_unmark_after_complete);
-#endif
   --e->count_committing_event_groups;
   mysql_mutex_unlock(&e->LOCK_parallel_entry);
 }
